// **************************************************************************
// ROOT macro: plot_total.c
// Plots the figures of total pair production cross section data. 
// There is one figure (now in png format, it can be modified) per element.
// -	cross section data of EPICS2014 (Z: 1-100) 
// -	cross section data of Livermore (Z: 1-99)   
// -	comparison of cross section data between Livermore and EPICS2014 (Z: 1-99) 
// The generated figures are saved in the corresponding directory:
// -	plots/total/comparison
// -	plots/total/epics2017
// -	plots/total/livermore

// Authors: Zhuxin LI @CENBG,France
// 2019.12.09
// **************************************************************************
TString sInt(Int_t number)
  {
    stringstream ss;
    ss << number;
	TString ts = ss.str();
    return ts;
  }
TString sDouble(Double_t number)
  {
    stringstream ss;
	ss << number;
    TString ts = ss.str();
    return ts;
  }
 	double RatioMax3[100];
	double RatioMax3_x[100];
	double RatioMax4[100];
	double RatioMax4_x[100];
  
enum DataToPlot
{
	
	Data2014,
	Data2017
	  	 
};
  
struct Info
{
 Info(int Z, int sub, double r1, double r2)
 :z(Z), subshellIndex(sub), ratio1Max(r1), ratio2Max(r2){}
 int z;
 int subshellIndex;
 double ratio1Max; // for low fit
 double ratio2Max; // for high fit
}; 
 
std::map<int, double> ratioMax;
  
int results=0;
int results1=0;
std::vector<int> resultsV;
int results2=0;
int results3=0;
int results4=0;
int results5=0;
std::vector<int> results5V;
int results6=0;
std::vector<int> results6V;
int results7=0;
std::vector<int> results7V;
int results8=0;
int results9=0;
	

void plotMaximalDifferenceOfFormFactorBetween2014And2017WithZ(){
	
	gROOT->Reset();	
	gSystem->Exec("mkdir -p plots/");
	


	double r_1[100]; 
	double r_2[100]; 
	
	
	double r_11[100]; 
	double r_12[100]; 
	double x[100];
	


	double r1, r2;	
	int z;
	std::ostringstream ost;
	ost <<"MaximalDifferenceOfFormFactorBetween2014And2017_final.txt";
	std::ifstream fin(ost.str().c_str());
	for(int i = 0; i<100;i++) // 1612 lines 
	{
		
		fin >> z >> r1;
		x[i] = z;
		r_1[i] = r1;
		cout<<z<<" "<<r1<<endl;
	}

	fin.close();
	
	
	
	gROOT->Reset();
	
	
	TCanvas* mycanvas = new TCanvas("g","Form Factors",800, 50, 800,600);
		
	mycanvas->SetGrid();
	
	
	
	mycanvas->cd();
	gPad->SetGrid();
	// gPad->SetLogx();
	// gPad->SetLogy();
	gPad->SetBottomMargin(0.15);
	gPad->SetLeftMargin(0.15);
		// gPad->SetLeftMargin(0.01);
		//gPad->SetLogy();
					
	auto mg = new TMultiGraph();
	TGraph *graph1 = new TGraph(100,x,r_1);		
		
		
		
	
	//region 3
	graph1->SetMarkerStyle(24);  // red point
	graph1->SetMarkerSize(1);
	graph1->SetMarkerColor(kRed);
	//graph1->SetLineWidth(2);
	graph1->SetLineColor(kRed);	
	mg->Add(graph1);	
	//region 3
		
		
		// // //set graph parameters of livermore
		
		
	mg->Draw("AP");
			
	mg->SetTitle("Maximal difference of FF of EPICS2017 compared to Livermore according to Z");		
	mg->GetXaxis()->SetTitle("Atomic number Z");
	mg->GetYaxis()->SetTitle("Relative difference (%)");
	
	// mg->GetXaxis()->SetTitleSize(0.06);
	// mg->GetYaxis()->SetTitleSize(0.06);
	
	// mg->GetXaxis()->SetLabelSize(0.05);
	// mg->GetYaxis()->SetLabelSize(0.05);
	// mg->GetYaxis()->SetLabelOffset(1.3);
	
	
	mg->GetXaxis()->CenterTitle();
	mg->GetYaxis()->CenterTitle();
	mg->GetXaxis()->SetLimits(0, 101);
	
	// TLegend* leg1 = new TLegend(0.7,0.15,0.9,0.35);
	// // leg1->SetTextAlign(12);
	// // leg1->SetFillColor(0);
	// // leg1->SetFillStyle(0);		
	// leg1->SetTextSize(0.04);
	
	// TString rname1 = "EPDL2017 (Poly 1)";
	
	// // TString rname23 = "Region 3 of EPDL2014";
	// // TString rname24 = "Region 4 of EPDL2014";
	
	// leg1->AddEntry(graph1,rname1);
	// // leg1->AddEntry(graph14,rname14);
	
	// // leg1->AddEntry(graph24,rname24);
	
	// // leg1->DrawClone("Same");
	// leg1->Draw();
	
		
		
	//******************	
		
		// mycanvas->cd(2);
		// gPad->SetGrid();
		// // gPad->SetLogx();
		// // gPad->SetLogy();
		// gPad->SetBottomMargin(0.15);
		// gPad->SetLeftMargin(0.12);
		// // gPad->SetLeftMargin(0.01);
		// //gPad->SetLogy();
		
		// auto mg1 = new TMultiGraph();
		// TGraph *graph2 = new TGraph(100,x,R_2);	
		// TGraph *graph22 = new TGraph(100,x,r_12);	
		
		// graph2->SetMarkerStyle(24);  // red point
		// graph2->SetMarkerSize(1);
		// graph2->SetMarkerColor(kRed);
		// //graph2->SetLineWidth(2);
		// graph2->SetLineColor(kRed);	
		// mg1->Add(graph2);
		
		// graph22->SetMarkerStyle(24);  // red point
		// graph22->SetMarkerSize(1);
		// graph22->SetMarkerColor(kBlue);
		// //graph22->SetLineWidth(2);
		// graph22->SetLineColor(kBlue);	
		// mg1->Add(graph22);
		
		// mg1->Draw("AP");
		// mg1->SetTitle("Maximal difference of fits in region 2 according to Z");		
		// mg1->GetXaxis()->SetTitle("Atomic number Z");
		// mg1->GetYaxis()->SetTitle("Relative difference (%)");
		
		// mg1->GetXaxis()->SetTitleSize(0.06);
		// mg1->GetYaxis()->SetTitleSize(0.06);
		
		// mg1->GetXaxis()->SetLabelSize(0.05);
		// mg1->GetYaxis()->SetLabelSize(0.05);
		
		// mg1->GetXaxis()->CenterTitle();
		// mg1->GetYaxis()->CenterTitle();
		// mg1->GetXaxis()->SetLimits(1,101);
		// TString rname2 = "EPDL2017 (Poly 4)";
		// TString rname12 = "EPDL2014 (Poly 3)";
	
		// TLegend* leg2 = new TLegend(0.12,0.15,0.35,0.35);
		// // leg2->SetTextAlign(12);
		// // leg2->SetFillColor(0);
		// // leg2->SetFillStyle(0);		
		// leg2->SetTextSize(0.04);
		
		
		
		// // leg2->AddEntry(graph13,rname13);
		// leg2->AddEntry(graph2,rname2);
		
		// // leg2->AddEntry(graph23,rname23);
		// leg2->AddEntry(graph22,rname12);
		
		// //leg2->DrawClone("Same");
		// leg2->Draw();
		
		
		
		
	
		mycanvas->Print("plots/MaximalDifferenceOfFormFactorBetween2014And2017WithZ.png");
		// delete mycanvas;
		// mycanvas = NULL;
		// mycanvas->Close();
		
	



}