// **************************************************************************
// ROOT macro: plot_total.c
// Plots the figures of total pair production cross section data. 
// There is one figure (now in png format, it can be modified) per element.
// -	cross section data of EPICS2014 (Z: 1-100) 
// -	cross section data of Livermore (Z: 1-99)   
// -	comparison of cross section data between Livermore and EPICS2014 (Z: 1-99) 
// The generated figures are saved in the corresponding directory:
// -	plots/total/comparison
// -	plots/total/epics2017
// -	plots/total/livermore

// Authors: Zhuxin LI @CENBG,France
// 2019.12.09
// **************************************************************************
TString sInt(Int_t number)
  {
    stringstream ss;
    ss << number;
	TString ts = ss.str();
    return ts;
  }
TString sDouble(Double_t number)
  {
    stringstream ss;
	ss << number;
    TString ts = ss.str();
    return ts;
  }
  
int results=0;
int results1=0;
std::vector<int> resultsV;
int results2=0;
int results3=0;
int results4=0;
int results5=0;
std::vector<int> results5V;


void plotSingle(Int_t z, Int_t plot, char*dir)
{
	gStyle->SetLegendTextSize(0.03);
	TString S = sInt(z);  
	
	TString title;
	
	
	if (plot == 1)
	{
		title = "Rayleigh scattering cross section of EPICS2017 for element Z = " + S;
		
	}
	else if(plot == 2)
	{
		title = "Rayleigh scattering cross section of Livermore for element Z = " + S;
	}
			
		
	Int_t num = 0;  
	Int_t ncols;
	double e, cs;
	Int_t loop = 0;
	char str[64] = "";
	
	
	FILE * fp = fopen(dir,"r");

	while(1)  
	{	
		loop++;
		// if loop = 1 we read the first header line
		fgets (str, 64, fp);
		// cout<<str<<endl;
		if(loop ==2)
		{
			// now loop = 2, we read the second header line, namely the number of points
			num = stoi(str);  
			cout<<"number of compton effect points:"<<num<<endl;
			break;
		}		
		
	}
	TString Tnum = sInt(num);
	
	double x[num];
	// array for total pair production data: cross section		
	double y[num]; 
	
	for(Int_t i = 0;i<num;++i)
	{
		// read one line energy cross section
		ncols = fscanf(fp,"%lf %lf",&e,&cs); 
		x[i]=e;   // keep energy
		y[i]=cs;  // keep cross section
		// printf("%.9e %.9e\n",x_1[i],y_1[i]);
	}
	fclose(fp);
	
	
    TCanvas* mycanvas = new TCanvas(S,S,500, 50, 800, 600);
		

	//TCanvas* mycanvas=new TCanvas(sz, sz, 200, 10, 1000, 1000);
	mycanvas->SetGrid();
	// mycanvas->SetLeftMargin(0.12);
	//mycanvas->SetFillColor(17);
	gPad->SetLogx();
	gPad->SetLogy();
	TGraph *graph = new TGraph(num,x,y);
	//graph->Draw("AC*");
	graph->Draw("APL");
	
	graph->SetMarkerStyle(7);  // red point
	graph->SetMarkerSize(2);
	graph->SetMarkerColor(2);
	//graph->SetLineWidth(2);
	graph->SetLineColor(2);
	
	graph->SetTitle(title);
	
	graph->GetXaxis()->SetTitle("Energy (MeV)");
	graph->GetYaxis()->SetTitle("Cross section (barn)");
	
	graph->GetXaxis()->CenterTitle();
	
	graph->GetYaxis()->CenterTitle();
	graph->GetYaxis()->SetTitleOffset(1.3);
	TLegend* leg = new TLegend(0.12,0.15,0.4,0.35);
	leg->SetFillColor(0);
	// leg->SetTextAlign(22);
	
	
	
	TString name;
	if (plot == 1)
	{
		name = "EPICS2017 - " + Tnum + " points";
		
	}
	else if(plot == 2)
	{
		name = "Livermore - " + Tnum + " points";
	}
	
	
	leg->AddEntry(graph,name);

	leg->Draw();
	
	
	
	
	if (plot == 1)
	{
		mycanvas->Print("plots/epics2017/re-cs-" + S + ".png");
		// mycanvas->Close();
	}
	else if(plot == 2)
	{
		mycanvas->Print("plots/epics2014/re-cs-" + S + ".png");
		// mycanvas->Close();
	}
		
		
}


// void plotComparison(Int_t z, char*dir1, char*dir2)
// {
	
	// gROOT->Reset();
		
	// TString S = sInt(z); 
	// TString title;
	// title = "Rayleigh scattering cross section for element Z = " + S;
		
		
	// Int_t num1 = 0;  
	// Int_t num2 = 0; 
	
	
	// Int_t ncols;
	// double e, cs;
	// Int_t loop = 0;
	// char str[64] = "";
	
	// FILE * fp1 = fopen(dir1,"r");
	
		// while(1)  
		// {	
			// loop++;
			// // if loop = 1 we read the first header line
			// fgets (str, 64, fp1);
			// // cout<<str<<endl;
			// if(loop ==2)
			// {
				// // now loop = 2, we read the second header line, namely the number of points
				// num1 = stoi(str);  
				// // cout<<"number of total pair production points:"<<num1<<endl;
				// break;
			// }		
			
		// }
		
		// // double x_1[num1];		
		// // double y_1[num1]; 
		
		
		// std::vector<double>  x_1;
		// std::vector<double>  y_1;
		
		// bool test =true;
		// for(Int_t i = 0;i<num1;++i)
		// {
			// // read one line energy cross section
			// ncols = fscanf(fp1,"%lf %lf",&e,&cs); 
			// // x_1[i]=e;   // keep energy
			// // y_1[i]=cs;  // keep cross section
			// x_1.push_back(e);  
			// y_1.push_back(cs);
			
			
			// // printf("%.9e %.9e\n",x_1[i],y_1[i]);
		// }
		// fclose(fp1);
		// // cout<<endl;
		
		
		
		
		
		
		// FILE * fp2 = fopen(dir2,"r");		
		// loop =0;
		
		// while(1)
		// {	
			// loop++;
			// // if loop = 1 we read the first header line
			// fgets (str, 64, fp2);
			// if(loop ==2)
			// {
				// // now loop = 2, we read the second header line, namely the number of points
				// num2 = stoi(str);  
				// // cout<<"number of total pair production points:"<<num2<<endl;
				// break;
			// }		
			
		// }
		

		// std::vector<double>  x_2;
		// std::vector<double>  y_2;
		
		
		// for(Int_t i = 0;i<num2;++i)
		// {
			// // read one line energy cross section
			// ncols = fscanf(fp2,"%lf %lf",&e,&cs); 
			// // x_2[i]=e; // keep energy
			// // y_2[i]=cs; // keep cross section
			
			// x_2.push_back(e);  
			// y_2.push_back(cs);
			
		// }
		// fclose(fp2);
		
		
		
		
		// TCanvas* mycanvas = new TCanvas(S,S,600, 10, 1000, 500);
		
		// mycanvas->SetGrid();
		// // mycanvas->Divide(1,2);
		// //TPad* pad1 = new TPad("pad1","This is pad1",0.05,0.52,0.95,0.97);
		// // TPad* pad1 = new TPad("pad1","This is pad1",0.0,0.4,1.0,1.0);
		// // TPad* pad2 = new TPad("pad2","This is pad2",0.0,0.0,1.0,0.4);
		// // pad1->Draw();
		// // pad2->Draw();
		
		// // pad2->cd();
		// // TPad* pad21 = new TPad("pad21","First subpad of pad2",0.1,0.0,0.5,1.0);
		// // TPad* pad22 = new TPad("pad22","Second subpad of pad2",0.5,0.0,0.9,1.0);
		// // pad21->Draw();
		// // pad22->Draw();
		
		
		// mycanvas->cd(1);
		// gPad->SetGrid();
		// gPad->SetLogx();
		// gPad->SetLogy();
		// gPad->SetBottomMargin(0.15);
		// gPad->SetLeftMargin(0.12);
		// // gPad->SetLeftMargin(0.01);
		// //gPad->SetLogy();
					
		// // TGraph *graph1 = new TGraph(num1,x_1,y_1);
		// // TGraph *graph2 = new TGraph(num2,x_2,y_2);
		// TGraph *graph1 = new TGraph(x_1.size(),x_1.data(),y_1.data());
		// TGraph *graph2 = new TGraph(x_2.size(),x_2.data(),y_2.data());
		
		// auto mg = new TMultiGraph();
		// //set graph parameters of livermore
		// graph2->SetMarkerStyle(4);  //blue circle
		// graph2->SetMarkerSize(0.7);
		// graph2->SetMarkerColor(4);
		// graph2->SetLineColor(4);
		
		// mg->Add(graph2);
	   
		
		// //set graph parameters of EPICS2014
		// graph1->SetMarkerStyle(7);  // red point
		// graph1->SetMarkerSize(2);
		// graph1->SetMarkerColor(2);
		// //graph1->SetLineWidth(2);
		// graph1->SetLineColor(2);	
		// mg->Add(graph1);
		// mg->Draw("APL");
				
		// mg->SetTitle(title);		
		// mg->GetXaxis()->SetTitle("Energy (MeV)");
		// mg->GetYaxis()->SetTitle("Cross section (barn)");
		
		// mg->GetXaxis()->SetTitleSize(0.06);
		// mg->GetYaxis()->SetTitleSize(0.06);
		// mg->GetYaxis()->SetTitleOffset(0.8);
		
		// mg->GetXaxis()->SetLabelSize(0.05);
		// mg->GetYaxis()->SetLabelSize(0.05);
		
		
		// mg->GetXaxis()->CenterTitle();
		// mg->GetYaxis()->CenterTitle();
		
		// // mg->GetXaxis()->SetLimits(1e-6,100000.);
		// mg->GetXaxis()->SetLimits(1e-6,1e-5);
		// // mg->GetXaxis()->SetLimits(0,13e-6);
		
		
		
		
		// // graph2->SetMaximum(5e-25); 
		// // graph2->SetMinimum(1e-35); 
		
		
		// // TLegend* leg = new TLegend(0.6,0.7,0.9,0.9);
		// TLegend* leg = new TLegend(0.12,0.15,0.4,0.35);
		// // leg->SetTextAlign(12);
		// leg->SetFillColor(0);	
		// leg->SetTextSize(0.04);
		
		
		// TString Tnum1 = sInt(x_1.size());		
		// TString Tnum2 = sInt(x_2.size());	
		
		// TString name1 = "EPDL2017 - "+ Tnum1 + " points";
		// TString name2 = "EPDL2014 - "+ Tnum2 + " points";		
		
		// leg->AddEntry(graph1,name1);
		// leg->AddEntry(graph2,name2);
		// //leg->DrawClone("Same");
		// leg->Draw();
		
		
		
		
		// mycanvas->Print("plots/comparison/2014vs2017-re-cs-"+ S +".png");
		// // mycanvas->Print("plots/comparison/zoom/2014vs2017-re-cs-"+ S +".png");
		// // mycanvas->Close();
		// // delete mycanvas;
		// // mycanvas = NULL;
		
// }


void plotComparison_for_publication(Int_t z, char*dir1, char*dir2)
{
	
	gROOT->Reset();
		
	TString S = sInt(z); 
	TString title;
	title = "Rayleigh scattering cross section for element Z = " + S;
		
		
	Int_t num1 = 0;  
	Int_t num2 = 0; 
	
	
	Int_t ncols;
	double e, cs;
	Int_t loop = 0;
	char str[64] = "";
	
	FILE * fp1 = fopen(dir1,"r");
	
		while(1)  
		{	
			loop++;
			// if loop = 1 we read the first header line
			fgets (str, 64, fp1);
			// cout<<str<<endl;
			if(loop ==2)
			{
				// now loop = 2, we read the second header line, namely the number of points
				num1 = stoi(str);  
				// cout<<"number of total pair production points:"<<num1<<endl;
				break;
			}		
			
		}
		
		// double x_1[num1];		
		// double y_1[num1]; 
		
		
		std::vector<double>  x_1;
		std::vector<double>  y_1;
		
		bool test =true;
		for(Int_t i = 0;i<num1;++i)
		{
			// read one line energy cross section
			ncols = fscanf(fp1,"%lf %lf",&e,&cs); 
			// x_1[i]=e;   // keep energy
			// y_1[i]=cs;  // keep cross section
			x_1.push_back(e);  
			y_1.push_back(cs);
			
			
			// printf("%.9e %.9e\n",x_1[i],y_1[i]);
		}
		fclose(fp1);
		// cout<<endl;
		
		
		
		
		
		
		FILE * fp2 = fopen(dir2,"r");		
		loop =0;
		
		while(1)
		{	
			loop++;
			// if loop = 1 we read the first header line
			fgets (str, 64, fp2);
			if(loop ==2)
			{
				// now loop = 2, we read the second header line, namely the number of points
				num2 = stoi(str);  
				// cout<<"number of total pair production points:"<<num2<<endl;
				break;
			}		
			
		}
		

		std::vector<double>  x_2;
		std::vector<double>  y_2;
		
		
		for(Int_t i = 0;i<num2;++i)
		{
			// read one line energy cross section
			ncols = fscanf(fp2,"%lf %lf",&e,&cs); 
			// x_2[i]=e; // keep energy
			// y_2[i]=cs; // keep cross section
			
			x_2.push_back(e);  
			y_2.push_back(cs);
			
		}
		fclose(fp2);
		
		
		
		
		TCanvas* mycanvas = new TCanvas(S,S,600, 10, 400, 400);
		
		mycanvas->SetGrid();
		// mycanvas->Divide(1,2);
		//TPad* pad1 = new TPad("pad1","This is pad1",0.05,0.52,0.95,0.97);
		// TPad* pad1 = new TPad("pad1","This is pad1",0.0,0.4,1.0,1.0);
		// TPad* pad2 = new TPad("pad2","This is pad2",0.0,0.0,1.0,0.4);
		// pad1->Draw();
		// pad2->Draw();
		
		// pad2->cd();
		// TPad* pad21 = new TPad("pad21","First subpad of pad2",0.1,0.0,0.5,1.0);
		// TPad* pad22 = new TPad("pad22","Second subpad of pad2",0.5,0.0,0.9,1.0);
		// pad21->Draw();
		// pad22->Draw();
		
		
		mycanvas->cd(1);
		gPad->SetGrid();
		gPad->SetLogx();
		gPad->SetLogy();
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.15);
		// gPad->SetLeftMargin(0.01);
		//gPad->SetLogy();
					
		// TGraph *graph1 = new TGraph(num1,x_1,y_1);
		// TGraph *graph2 = new TGraph(num2,x_2,y_2);
		TGraph *graph1 = new TGraph(x_1.size(),x_1.data(),y_1.data());
		TGraph *graph2 = new TGraph(x_2.size(),x_2.data(),y_2.data());
		
		auto mg = new TMultiGraph();
		//set graph parameters of livermore
		
	   
		
		//set graph parameters of EPICS2017
		graph1->SetMarkerStyle(24);  // red point
		graph1->SetMarkerSize(1.2);
		graph1->SetMarkerColor(kRed);
		//graph1->SetLineWidth(2);
		graph1->SetLineColor(kRed);	
		mg->Add(graph1);
		mg->Draw("AP");
		
		graph2->SetMarkerStyle(21);  //blue circle
		graph2->SetMarkerSize(0.8);
		graph2->SetMarkerColor(kBlue);
		graph2->SetLineColor(kBlue);
		
		mg->Add(graph2);
		
				
		// mg->SetTitle(title);		
		mg->GetXaxis()->SetTitle("Energy (MeV)");
		mg->GetYaxis()->SetTitle("Cross section (barn)");
		
		// mg->GetXaxis()->SetTitleSize(0.06);
		// mg->GetYaxis()->SetTitleSize(0.06);
		// mg->GetYaxis()->SetTitleOffset(0.8);
		
		// mg->GetXaxis()->SetLabelSize(0.05);
		// mg->GetYaxis()->SetLabelSize(0.05);
		
		
		mg->GetXaxis()->CenterTitle();
		mg->GetYaxis()->CenterTitle();
		
		mg->GetXaxis()->SetTitleOffset(1.5);
		mg->GetYaxis()->SetTitleOffset(2);
		
		// mg->GetXaxis()->SetLimits(1e-6,100000.);
		// mg->GetXaxis()->SetLimits(1e-6,1e-5);
		// mg->GetXaxis()->SetLimits(0,13e-6);
		
		
		TGaxis *axisX = new TGaxis(TMath::Power(10, gPad->GetUxmin()) ,TMath::Power(10, gPad->GetUymax()),
		TMath::Power(10, gPad->GetUxmax()), TMath::Power(10, gPad->GetUymax()),
		mg->GetXaxis()->GetXmin(),
		mg->GetXaxis()->GetXmax(), 510,"GU-");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisX->Draw("");
			
		
		TGaxis *axisY = new TGaxis(TMath::Power(10, gPad->GetUxmax()),TMath::Power(10, gPad->GetUymin()) ,
		TMath::Power(10, gPad->GetUxmax()), TMath::Power(10, gPad->GetUymax()) ,
		mg->GetYaxis()->GetXmin(),
		mg->GetYaxis()->GetXmax(), 510,"GU+");
		
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisY->Draw();
		
		// graph2->SetMaximum(5e-25); 
		// graph2->SetMinimum(1e-35); 
		
		
		// TLegend* leg = new TLegend(0.6,0.7,0.9,0.9);
		TLegend* leg = new TLegend(0.12,0.15,0.4,0.35);
		// leg->SetTextAlign(12);
		leg->SetFillColor(0);	
		leg->SetTextSize(0.04);
		
		
		TString Tnum1 = sInt(x_1.size());		
		TString Tnum2 = sInt(x_2.size());	
		
		TString name1 = "EPDL2017 - "+ Tnum1 + " points";
		TString name2 = "EPDL2014 - "+ Tnum2 + " points";		
		
		leg->AddEntry(graph1,name1);
		leg->AddEntry(graph2,name2);
		//leg->DrawClone("Same");
		// leg->Draw();
		
		
		
		
		mycanvas->Print("plots/comparison/2014vs2017-re-cs-"+ S +".png");
		// mycanvas->Print("plots/comparison/zoom/2014vs2017-re-cs-"+ S +".png");
		// mycanvas->Close();
		// delete mycanvas;
		// mycanvas = NULL;
		
}


void plot_cs(){
	
	gROOT->Reset();
	// create the 2 directories if they do not exist if
	gSystem->Exec("mkdir -p plots/epics2017");
	gSystem->Exec("mkdir -p plots/epics2014");
	gSystem->Exec("mkdir -p plots/comparison");
	// gSystem->Exec("mkdir -p plots/comparison/zoom");
	
    
	for (Int_t z = 1;z<=100;++z)// number of element Z, from 1 to 100
	{		
		// if((z != 1) && (z != 13) && (z != 82)) continue;
		
		char path1Format[128] = "epics2017/raylCS/re-cs-%d.dat"; //prefix of the name of original data file
		char path1[128];
		
		char path2Format[128] = "epics2014/raylCS/re-cs-%d.dat"; //prefix of the name of original data file
		char path2[128];
		
		sprintf(path1,path1Format, z);
		sprintf(path2,path2Format, z);
		
		// plotSingle(z,1,path1);
		// plotSingle(z,2,path2);			
		// plotComparison(z, path1, path2);
		plotComparison_for_publication(z, path1, path2);
		
			
	}
	cout<<"results="<<results<<", results2="<<results2<<", results3="<<results3<<endl;
	cout<<"results1="<<results1<<endl;
	cout<<"for the following elements, all points in EPICS2014 are found in EPICS2017"
	<<endl;
	for(std::vector<int>::iterator it = resultsV.begin(); it!=resultsV.end(); it++)
	{
		cout<<*it<<endl;
	}
	
	cout<<"results4="<<results4<<" Only two elements do not have errors of overlapping energy pairs,\
	namely element 1 and 2"<<endl;
	
	cout<<"results5="<<results5<<endl;
	cout<<"for the following elements, it has exceptions due to the precision"<<endl;
	
	for(std::vector<int>::iterator it = results5V.begin(); it!=results5V.end(); it++)
	{
		cout<<*it<<endl;
	}
	
	
}